@@ -8,64 +8,77 @@ import java.io.ByteArrayOutputStream;
 import java.io.IOException;
 import java.io.OutputStream;
 import java.net.InetAddress;
+import java.util.Collection;
+import java.util.Collections;
 import java.util.Enumeration;
 import java.util.Hashtable;
+import java.util.Map;
 import java.util.TimerTask;
 import java.util.Vector;
-import java.util.logging.Logger;
 
 import javax.jmdns.ServiceInfo;
 import javax.jmdns.impl.DNSRecord.Pointer;
 import javax.jmdns.impl.DNSRecord.Service;
 import javax.jmdns.impl.DNSRecord.Text;
+import javax.jmdns.impl.constants.DNSRecordClass;
+import javax.jmdns.impl.constants.DNSRecordType;
+import javax.jmdns.impl.constants.DNSState;
 
 /**
  * JmDNS service information.
  *
  * @version %I%, %G%
- * @author	Arthur van Hoff, Jeff Sonstein, Werner Randelshofer
+ * @author Arthur van Hoff, Jeff Sonstein, Werner Randelshofer
  */
 public class ServiceInfoImpl extends ServiceInfo implements DNSListener
 {
-    private static Logger logger = Logger.getLogger(ServiceInfoImpl.class.getName());
-    private JmDNSImpl dns;
-    
+    // private static Logger logger = Logger.getLogger(ServiceInfoImpl.class.getName());
+    private JmDNSImpl _dns;
+
     // State machine
     /**
-     * The state of this service info.
-     * This is used only for services announced by JmDNS.
+     * The state of this service info. This is used only for services announced by JmDNS.
      * <p/>
-     * For proper handling of concurrency, this variable must be
-     * changed only using methods advanceState(), revertState() and cancel().
+     * For proper handling of concurrency, this variable must be changed only using methods advanceState(),
+     * revertState() and cancel().
      */
-    private DNSState state = DNSState.PROBING_1;
+    private volatile DNSState _state = DNSState.PROBING_1;
 
     /**
-     * Task associated to this service info.
-     * Possible tasks are JmDNS.Prober, JmDNS.Announcer, JmDNS.Responder,
+     * Task associated to this service info. Possible tasks are JmDNS.Prober, JmDNS.Announcer, JmDNS.Responder,
      * JmDNS.Canceler.
      */
-    private TimerTask task;
+    private TimerTask _task;
 
-    String type;
-    private String name;
-    String server;
-    int port;
-    int weight;
-    int priority;
-    private byte text[];
-    Hashtable props;
-    InetAddress addr;
+    private String _type;
+    private String _name;
+    private String _server;
+    private int _port;
+    private int _weight;
+    private int _priority;
+    private byte _text[];
+    private Map<String, Object> _props;
+    private InetAddress _addr;
 
     /**
+     * @param type
+     * @param name
+     * @param port
+     * @param text
      * @see javax.jmdns.ServiceInfo#create(String, String, int, String)
      */
     public ServiceInfoImpl(String type, String name, int port, String text)
     {
         this(type, name, port, 0, 0, text);
     }
-    
+
     /**
+     * @param type
+     * @param name
+     * @param port
+     * @param weight
+     * @param priority
+     * @param text
      * @see javax.jmdns.ServiceInfo#create(String, String, int, int, int, String)
      */
     public ServiceInfoImpl(String type, String name, int port, int weight, int priority, String text)
@@ -75,7 +88,7 @@ public class ServiceInfoImpl extends ServiceInfo implements DNSListener
         {
             ByteArrayOutputStream out = new ByteArrayOutputStream(text.length());
             writeUTF(out, text);
-            byte [] data = out.toByteArray();
+            byte[] data = out.toByteArray();
             this.setText(new byte[data.length + 1]);
             this.getText()[0] = (byte) data.length;
             System.arraycopy(data, 0, this.getText(), 1, data.length);
@@ -87,9 +100,15 @@ public class ServiceInfoImpl extends ServiceInfo implements DNSListener
     }
 
     /**
-     * @see javax.jmdns.ServiceInfo#create(String, String, int, int, int, Hashtable)
+     * @param type
+     * @param name
+     * @param port
+     * @param weight
+     * @param priority
+     * @param props
+     * @see javax.jmdns.ServiceInfo#create(String, String, int, int, int, Map)
      */
-    public ServiceInfoImpl(String type, String name, int port, int weight, int priority, Hashtable props)
+    public ServiceInfoImpl(String type, String name, int port, int weight, int priority, Map<String, ?> props)
     {
         this(type, name, port, weight, priority, new byte[0]);
         if (props != null)
@@ -97,9 +116,8 @@ public class ServiceInfoImpl extends ServiceInfo implements DNSListener
             try
             {
                 ByteArrayOutputStream out = new ByteArrayOutputStream(256);
-                for (Enumeration e = props.keys(); e.hasMoreElements();)
+                for (String key : props.keySet())
                 {
-                    String key = (String) e.nextElement();
                     Object val = props.get(key);
                     ByteArrayOutputStream out2 = new ByteArrayOutputStream(100);
                     writeUTF(out2, key);
@@ -138,20 +156,29 @@ public class ServiceInfoImpl extends ServiceInfo implements DNSListener
     }
 
     /**
+     * @param type
+     * @param name
+     * @param port
+     * @param weight
+     * @param priority
+     * @param text
      * @see javax.jmdns.ServiceInfo#create(String, String, int, int, int, byte[])
      */
     public ServiceInfoImpl(String type, String name, int port, int weight, int priority, byte text[])
     {
-        this.type = type;
-        this.name = name;
-        this.port = port;
-        this.weight = weight;
-        this.priority = priority;
+        this._type = type;
+        this._name = name;
+        this._port = port;
+        this._weight = weight;
+        this._priority = priority;
         this.setText(text);
     }
 
     /**
      * Construct a service record during service discovery.
+     *
+     * @param type
+     * @param name
      */
     ServiceInfoImpl(String type, String name)
     {
@@ -160,116 +187,153 @@ public class ServiceInfoImpl extends ServiceInfo implements DNSListener
             throw new IllegalArgumentException("type must be fully qualified DNS name ending in '.': " + type);
         }
 
-        this.type = type;
-        this.name = name;
+        this._type = type;
+        this._name = name;
     }
 
     /**
      * During recovery we need to duplicate service info to reregister them
      */
-    ServiceInfoImpl(ServiceInfoImpl info)
+    ServiceInfoImpl(ServiceInfo info)
     {
         if (info != null)
         {
-            this.type = info.type;
-            this.name = info.name;
-            this.port = info.port;
-            this.weight = info.weight;
-            this.priority = info.priority;
-            this.setText(info.getText());
+            this._type = info.getType();
+            this._name = info.getName();
+            this._port = info.getPort();
+            this._weight = info.getWeight();
+            this._priority = info.getPriority();
+            this.setText(info.getTextBytes());
         }
     }
 
     /**
      * @see javax.jmdns.ServiceInfo#getType()
      */
+    @Override
     public String getType()
     {
-        return type;
+        return _type;
     }
 
     /**
      * @see javax.jmdns.ServiceInfo#getName()
      */
+    @Override
     public String getName()
     {
-        return name;
+        return _name;
     }
 
     /**
      * Sets the service instance name.
      *
-     * @param name unqualified service instance name, such as <code>foobar</code>
+     * @param name
+     *            unqualified service instance name, such as <code>foobar</code>
      */
     void setName(String name)
     {
-        this.name = name;
+        this._name = name;
     }
 
     /**
      * @see javax.jmdns.ServiceInfo#getQualifiedName()
      */
+    @Override
     public String getQualifiedName()
     {
-        return name + "." + type;
+        return _name + "." + _type;
     }
 
     /**
      * @see javax.jmdns.ServiceInfo#getServer()
      */
+    @Override
     public String getServer()
     {
-        return server;
+        return _server;
+    }
+
+    /**
+     * @param server
+     *            the server to set
+     */
+    void setServer(String server)
+    {
+        this._server = server;
     }
 
     /**
      * @see javax.jmdns.ServiceInfo#getHostAddress()
      */
+    @Override
     public String getHostAddress()
     {
-        return (addr != null ? addr.getHostAddress() : "");
+        return (_addr != null ? _addr.getHostAddress() : "");
     }
 
+    /*
+     * (non-Javadoc)
+     *
+     * @see javax.jmdns.ServiceInfo#getAddress()
+     */
+    @Override
     public InetAddress getAddress()
     {
-        return addr;
+        return _addr;
     }
 
     /**
+     * @param addr
+     *            the addr to set
+     */
+    void setAddress(InetAddress addr)
+    {
+        this._addr = addr;
+    }
+
+    /*
+     * (non-Javadoc)
+     *
      * @see javax.jmdns.ServiceInfo#getInetAddress()
      */
+    @Override
     public InetAddress getInetAddress()
     {
-        return addr;
+        return _addr;
     }
 
     /**
      * @see javax.jmdns.ServiceInfo#getPort()
      */
+    @Override
     public int getPort()
     {
-        return port;
+        return _port;
     }
 
     /**
      * @see javax.jmdns.ServiceInfo#getPriority()
      */
+    @Override
     public int getPriority()
     {
-        return priority;
+        return _priority;
     }
 
     /**
      * @see javax.jmdns.ServiceInfo#getWeight()
      */
+    @Override
     public int getWeight()
     {
-        return weight;
+        return _weight;
     }
 
     /**
      * @see javax.jmdns.ServiceInfo#getTextBytes()
      */
+    @Override
     public byte[] getTextBytes()
     {
         return getText();
@@ -278,6 +342,7 @@ public class ServiceInfoImpl extends ServiceInfo implements DNSListener
     /**
      * @see javax.jmdns.ServiceInfo#getTextString()
      */
+    @Override
     public String getTextString()
     {
         if ((getText() == null) || (getText().length == 0) || ((getText().length == 1) && (getText()[0] == 0)))
@@ -290,6 +355,7 @@ public class ServiceInfoImpl extends ServiceInfo implements DNSListener
     /**
      * @see javax.jmdns.ServiceInfo#getURL()
      */
+    @Override
     public String getURL()
     {
         return getURL("http");
@@ -298,6 +364,7 @@ public class ServiceInfoImpl extends ServiceInfo implements DNSListener
     /**
      * @see javax.jmdns.ServiceInfo#getURL(java.lang.String)
      */
+    @Override
     public String getURL(String protocol)
     {
         String url = protocol + "://" + getHostAddress() + ":" + getPort();
@@ -316,17 +383,23 @@ public class ServiceInfoImpl extends ServiceInfo implements DNSListener
         return url;
     }
 
-    /**
+    /*
+     * (non-Javadoc)
+     *
      * @see javax.jmdns.ServiceInfo#getPropertyBytes(java.lang.String)
      */
+    @Override
     public synchronized byte[] getPropertyBytes(String name)
     {
         return (byte[]) getProperties().get(name);
     }
 
-    /**
+    /*
+     * (non-Javadoc)
+     *
      * @see javax.jmdns.ServiceInfo#getPropertyString(java.lang.String)
      */
+    @Override
     public synchronized String getPropertyString(String name)
     {
         byte data[] = (byte[]) getProperties().get(name);
@@ -341,13 +414,17 @@ public class ServiceInfoImpl extends ServiceInfo implements DNSListener
         return readUTF(data, 0, data.length);
     }
 
-    /**
+    /*
+     * (non-Javadoc)
+     *
      * @see javax.jmdns.ServiceInfo#getPropertyNames()
      */
-    public Enumeration getPropertyNames()
+    @Override
+    public Enumeration<String> getPropertyNames()
     {
-        Hashtable props = getProperties();
-        return (props != null) ? props.keys() : new Vector().elements();
+        Map<String, Object> properties = getProperties();
+        Collection<String> names = (properties != null ? properties.keySet() : Collections.<String> emptySet());
+        return new Vector<String>(names).elements();
     }
 
     /**
@@ -384,10 +461,11 @@ public class ServiceInfoImpl extends ServiceInfo implements DNSListener
      */
     String readUTF(byte data[], int off, int len)
     {
+        int offset = off;
         StringBuffer buf = new StringBuffer();
-        for (int end = off + len; off < end;)
+        for (int end = offset + len; offset < end;)
         {
-            int ch = data[off++] & 0xFF;
+            int ch = data[offset++] & 0xFF;
             switch (ch >> 4)
             {
                 case 0:
@@ -402,28 +480,28 @@ public class ServiceInfoImpl extends ServiceInfo implements DNSListener
                     break;
                 case 12:
                 case 13:
-                    if (off >= len)
+                    if (offset >= len)
                     {
                         return null;
                     }
-                    // 110x xxxx   10xx xxxx
-                    ch = ((ch & 0x1F) << 6) | (data[off++] & 0x3F);
+                    // 110x xxxx 10xx xxxx
+                    ch = ((ch & 0x1F) << 6) | (data[offset++] & 0x3F);
                     break;
                 case 14:
-                    if (off + 2 >= len)
+                    if (offset + 2 >= len)
                     {
                         return null;
                     }
-                    // 1110 xxxx  10xx xxxx  10xx xxxx
-                    ch = ((ch & 0x0f) << 12) | ((data[off++] & 0x3F) << 6) | (data[off++] & 0x3F);
+                    // 1110 xxxx 10xx xxxx 10xx xxxx
+                    ch = ((ch & 0x0f) << 12) | ((data[offset++] & 0x3F) << 6) | (data[offset++] & 0x3F);
                     break;
                 default:
-                    if (off + 1 >= len)
+                    if (offset + 1 >= len)
                     {
                         return null;
                     }
-                    // 10xx xxxx,  1111 xxxx
-                    ch = ((ch & 0x3F) << 4) | (data[off++] & 0x0f);
+                    // 10xx xxxx, 1111 xxxx
+                    ch = ((ch & 0x3F) << 4) | (data[offset++] & 0x0f);
                     break;
             }
             buf.append((char) ch);
@@ -431,11 +509,11 @@ public class ServiceInfoImpl extends ServiceInfo implements DNSListener
         return buf.toString();
     }
 
-    synchronized Hashtable getProperties()
+    synchronized Map<String, Object> getProperties()
     {
-        if ((props == null) && (getText() != null))
+        if ((_props == null) && (getText() != null))
         {
-            Hashtable props = new Hashtable();
+            Hashtable<String, Object> properties = new Hashtable<String, Object>();
             int off = 0;
             while (off < getText().length)
             {
@@ -443,78 +521,90 @@ public class ServiceInfoImpl extends ServiceInfo implements DNSListener
                 int len = getText()[off++] & 0xFF;
                 if ((len == 0) || (off + len > getText().length))
                 {
-                    props.clear();
+                    properties.clear();
                     break;
                 }
                 // look for the '='
                 int i = 0;
                 for (; (i < len) && (getText()[off + i] != '='); i++)
                 {
-                    ;
+                    /* Stub */
                 }
 
                 // get the property name
                 String name = readUTF(getText(), off, i);
                 if (name == null)
                 {
-                    props.clear();
+                    properties.clear();
                     break;
                 }
                 if (i == len)
                 {
-                    props.put(name, NO_VALUE);
+                    properties.put(name, NO_VALUE);
                 }
                 else
                 {
                     byte value[] = new byte[len - ++i];
                     System.arraycopy(getText(), off + i, value, 0, len - i);
-                    props.put(name, value);
+                    properties.put(name, value);
                     off += len;
                 }
             }
-            this.props = props;
+            this._props = properties;
         }
-        return props;
+        return _props;
     }
-    
+
     /**
      * JmDNS callback to update a DNS record.
+     *
+     * @param dnsCache
+     * @param now
+     * @param rec
      */
-    public void updateRecord(JmDNSImpl jmdns, long now, DNSRecord rec)
+    public void updateRecord(DNSCache dnsCache, long now, DNSEntry rec)
     {
         if ((rec != null) && !rec.isExpired(now))
         {
-            switch (rec.type)
+            switch (rec.getRecordType())
             {
-                case DNSConstants.TYPE_A:		// IPv4
-                case DNSConstants.TYPE_AAAA:	// IPv6 FIXME [PJYF Oct 14 2004] This has not been tested
-                    if (rec.name.equals(server))
+                case TYPE_A: // IPv4
+                case TYPE_AAAA: // IPv6 FIXME [PJYF Oct 14 2004]
+                    // This has not been tested
+                    if (rec._name.equals(_server))
                     {
-                        addr = ((DNSRecord.Address) rec).getAddress();
+                        _addr = ((DNSRecord.Address) rec).getAddress();
 
                     }
                     break;
-                case DNSConstants.TYPE_SRV:
-                    if (rec.name.equals(getQualifiedName()))
+                case TYPE_SRV:
+                    if (rec._name.equals(getQualifiedName()))
                     {
                         DNSRecord.Service srv = (DNSRecord.Service) rec;
-                        server = srv.server;
-                        port = srv.port;
-                        weight = srv.weight;
-                        priority = srv.priority;
-                        addr = null;
+                        _server = srv._server;
+                        _port = srv._port;
+                        _weight = srv._weight;
+                        _priority = srv._priority;
+                        _addr = null;
                         // changed to use getCache() instead - jeffs
-                        // updateRecord(jmdns, now, (DNSRecord)jmdns.cache.get(server, TYPE_A, CLASS_IN));
-                        updateRecord(jmdns, now, (DNSRecord) jmdns.getCache().get(server, DNSConstants.TYPE_A, DNSConstants.CLASS_IN));
+                        // updateRecord(jmdns, now,
+                        // (DNSRecord)jmdns.cache.get(server, TYPE_A,
+                        // CLASS_IN));
+                        // updateRecord(jmdns, now, (DNSRecord) jmdns.getCache().get(_server, DNSConstants.TYPE_A,
+                        // DNSConstants.CLASS_IN));
+                        updateRecord(dnsCache, now, dnsCache.getDNSEntry(_server, DNSRecordType.TYPE_A,
+                                DNSRecordClass.CLASS_IN));
                     }
                     break;
-                case DNSConstants.TYPE_TXT:
-                    if (rec.name.equals(getQualifiedName()))
+                case TYPE_TXT:
+                    if (rec._name.equals(getQualifiedName()))
                     {
                         DNSRecord.Text txt = (DNSRecord.Text) rec;
-                        setText(txt.text);
+                        setText(txt._text);
                     }
                     break;
+                default:
+                    break;
             }
             // Future Design Pattern
             // This is done, to notify the wait loop in method
@@ -531,22 +621,13 @@ public class ServiceInfoImpl extends ServiceInfo implements DNSListener
         }
     }
 
-    /**
-     * Returns true if the service info is filled with data.
-     */
-    public boolean hasData()
-    {
-        return server != null && addr != null && getText() != null;
-    }
-    
-    
     // State machine
     /**
      * Sets the state and notifies all objects that wait on the ServiceInfo.
      */
     public synchronized void advanceState()
     {
-        state = state.advance();
+        _state = _state.advance();
         notifyAll();
     }
 
@@ -555,7 +636,7 @@ public class ServiceInfoImpl extends ServiceInfo implements DNSListener
      */
     synchronized void revertState()
     {
-        state = state.revert();
+        _state = _state.revert();
         notifyAll();
     }
 
@@ -564,29 +645,49 @@ public class ServiceInfoImpl extends ServiceInfo implements DNSListener
      */
     synchronized void cancel()
     {
-        state = DNSState.CANCELED;
+        _state = DNSState.CANCELED;
         notifyAll();
     }
 
     /**
      * Returns the current state of this info.
+     *
+     * @return current state
      */
     public DNSState getState()
     {
-        return state;
+        return _state;
     }
 
-
+    /*
+     * (non-Javadoc)
+     *
+     * @see java.lang.Object#hashCode()
+     */
+    @Override
     public int hashCode()
     {
         return getQualifiedName().hashCode();
     }
 
+    /*
+     * (non-Javadoc)
+     *
+     * @see java.lang.Object#equals(java.lang.Object)
+     */
+    @Override
     public boolean equals(Object obj)
     {
-        return (obj instanceof ServiceInfoImpl) && getQualifiedName().equals(((ServiceInfoImpl) obj).getQualifiedName());
+        return (obj instanceof ServiceInfoImpl)
+                && getQualifiedName().equals(((ServiceInfoImpl) obj).getQualifiedName());
     }
 
+    /*
+     * (non-Javadoc)
+     *
+     * @see javax.jmdns.ServiceInfo#getNiceTextString()
+     */
+    @Override
     public String getNiceTextString()
     {
         StringBuffer buf = new StringBuffer();
@@ -611,6 +712,12 @@ public class ServiceInfoImpl extends ServiceInfo implements DNSListener
         return buf.toString();
     }
 
+    /*
+     * (non-Javadoc)
+     *
+     * @see java.lang.Object#toString()
+     */
+    @Override
     public String toString()
     {
         StringBuffer buf = new StringBuffer();
@@ -619,50 +726,50 @@ public class ServiceInfoImpl extends ServiceInfo implements DNSListener
         buf.append(',');
         buf.append(getAddress());
         buf.append(':');
-        buf.append(port);
+        buf.append(_port);
         buf.append(',');
         buf.append(getNiceTextString());
         buf.append(']');
         return buf.toString();
     }
 
-	public void addAnswers(DNSOutgoing out, int ttl, HostInfo localHost) throws IOException
+    public void addAnswers(DNSOutgoing out, int ttl, HostInfo localHost) throws IOException
     {
-        out.addAnswer(new Pointer(type, DNSConstants.TYPE_PTR, DNSConstants.CLASS_IN, ttl,
-                getQualifiedName()), 0);
-        out.addAnswer(new Service(getQualifiedName(), DNSConstants.TYPE_SRV, DNSConstants.CLASS_IN|DNSConstants.CLASS_UNIQUE,
-                ttl, priority, weight, port, localHost.getName()), 0);
-        out.addAnswer(new Text(getQualifiedName(), DNSConstants.TYPE_TXT, DNSConstants.CLASS_IN|DNSConstants.CLASS_UNIQUE,
-                ttl, getText()), 0);
+        out.addAnswer(new Pointer(_type, DNSRecordType.TYPE_PTR, DNSRecordClass.CLASS_IN, DNSRecordClass.NOT_UNIQUE,
+                ttl, getQualifiedName()), 0);
+        out.addAnswer(new Service(getQualifiedName(), DNSRecordType.TYPE_SRV, DNSRecordClass.CLASS_IN,
+                DNSRecordClass.UNIQUE, ttl, _priority, _weight, _port, localHost.getName()), 0);
+        out.addAnswer(new Text(getQualifiedName(), DNSRecordType.TYPE_TXT, DNSRecordClass.CLASS_IN,
+                DNSRecordClass.UNIQUE, ttl, getText()), 0);
     }
 
     public void setTask(TimerTask task)
     {
-        this.task = task;
+        this._task = task;
     }
 
     public TimerTask getTask()
     {
-        return task;
+        return _task;
     }
 
-    public void setText(byte [] text)
+    public void setText(byte[] text)
     {
-        this.text = text;
+        this._text = text;
     }
 
-    public byte [] getText()
+    public byte[] getText()
     {
-        return text;
+        return _text;
     }
 
     public void setDns(JmDNSImpl dns)
     {
-        this.dns = dns;
+        this._dns = dns;
     }
 
     public JmDNSImpl getDns()
     {
-        return dns;
+        return _dns;
     }
 }
